@@ -5,6 +5,8 @@ using InteractiveUtils
 # Builtins not present in 1.10 (the lowest supported version)
 const RECENTLY_ADDED = Core.Builtin[
     Core.current_scope,
+    Core.declare_const,
+    Core.declare_global,
     isdefinedglobal,
     Core.memorynew,
     Core.memoryref_isassigned,
@@ -155,7 +157,7 @@ const kwinvoke = Core.kwfunc(Core.invoke)
 
 function maybe_recurse_expanded_builtin(interp::Interpreter, frame::Frame, new_expr::Expr)
     f = new_expr.args[1]
-    if isa(f, Core.Builtin) || isa(f, Core.IntrinsicFunction)
+    if supertype(typeof(f)) === Core.Builtin || isa(f, Core.IntrinsicFunction)
         return maybe_evaluate_builtin(interp, frame, new_expr, true)
     else
         return new_expr
@@ -190,7 +192,7 @@ function maybe_evaluate_builtin(interp::Interpreter, frame::Frame, call_expr::Ex
         end
         return Some{Any}(f(args...))
     end
-    if !(isa(f, Core.Builtin) || isa(f, Core.IntrinsicFunction))
+    if !(supertype(typeof(f)) === Core.Builtin || isa(f, Core.IntrinsicFunction))
         return call_expr
     end
     # By having each call appearing statically in the "switch" block below,
@@ -210,7 +212,9 @@ function maybe_evaluate_builtin(interp::Interpreter, frame::Frame, call_expr::Ex
             print(io,
 """
     $head f === tuple
-        return Some{Any}(ntupleany(i::Int->lookup(interp, frame, args[i+1]), length(args)-1))
+        let args=args
+            return Some{Any}(ntupleany(i::Int->lookup(interp, frame, args[i+1]), length(args)-1))
+        end
 """)
             continue
         elseif f === Core._apply_iterate
