@@ -372,7 +372,7 @@ Return the deepest callee in the call stack.
 leaf(frame) = traverse(callee, frame)
 
 function Base.show(io::IO, frame::Frame)
-    frame_loc = CodeTracking.replace_buildbot_stdlibpath(repr(scopeof(frame)))
+    frame_loc = Base.fixup_stdlib_path(repr(scopeof(frame)))
     println(io, "Frame for ", frame_loc)
     pc = frame.pc
     ns = nstatements(frame.framecode)
@@ -500,7 +500,7 @@ struct BreakpointSignature <: AbstractBreakpoint
     sig::Union{Nothing, Type}
     line::Int # 0 is a sentinel for first statement
     condition::Condition
-    enabled::Ref{Bool}
+    enabled::Base.RefValue{Bool}
     instances::Vector{BreakpointRef}
 end
 same_location(bp2::BreakpointSignature, bp::BreakpointSignature) =
@@ -539,7 +539,7 @@ struct BreakpointFileLocation <: AbstractBreakpoint
     abspath::String
     line::Int
     condition::Condition
-    enabled::Ref{Bool}
+    enabled::Base.RefValue{Bool}
     instances::Vector{BreakpointRef}
 end
 same_location(bp2::BreakpointFileLocation, bp::BreakpointFileLocation) =
