@@ -1,7 +1,8 @@
 using Test, DeepDiffs
 
-@static if !Base.GIT_VERSION_INFO.tagged_commit && # only run on nightly
-    !Sys.iswindows() # TODO: Understand why this fails, probably some line endings
+@static if get(ENV, "GITHUB_ACTION", nothing) === nothing &&  # on CI we have a separate action to run this test
+        !Base.GIT_VERSION_INFO.tagged_commit && # only run on nightly
+        !Sys.iswindows() # TODO: Understand why this fails, probably some line endings
     @testset "Check builtin.jl consistency" begin
         builtins_path = joinpath(@__DIR__, "..", "src", "builtins.jl")
         old_builtins = read(builtins_path, String)
